import java.awt.*;
import java.awt.geom.*;
import java.io.Serializable;

public abstract class Alakzat implements Serializable
{
    public static final int NORMÁL = 0;
    public static final int SZAGGATOTT = 1;
    public static final int PONTOZOTT = 2;
    public static final int SZAGGATOTTPONTOZOTT = 3;

    protected Point         kezdőpont;
    protected Point         végpont;
    protected Color         vonal;
    protected Color         töltő;
    protected boolean       töltött;
    protected float         vastagság;
    protected int           stílusérték;
    protected transient BasicStroke   stílus;   // nem írjuk ki (nem Serializable)

    /**
     * Alakzat létrehozása
     * @param p kezdőpont és végpont
     * @param vsz vonalszín
     * @param tsz töltőszín
     * @param t kitöltött-e
     * @param v vonalvastagság
     * @param s vonalstílus
     */
    protected Alakzat(Point p, Color vsz, Color tsz, boolean t, float v, int st)
    {
        kezdőpont = new Point(p);   végpont = new Point(p);
        vonal = vsz;    töltő = tsz;
        töltött = t;    vastagság = v;
        stílusérték = st;
        stílus = vonalstílus();
    }

    /**
     * Alakzat másolatának létrehozása
     * paraméterek, mint konstruktorban
     * @return egy új alakzat
     */
    public abstract Alakzat másol(Point p, Color vsz, Color tsz, boolean t, float v, int st);

    /**
     * Kirajzolja az alakzatot
     * @param g a rajzolás helye
     */
    public abstract void rajzol(Graphics2D g);

    /**
     * Az alakzattípus neve
     * @return a típust megadó név
     */
    public abstract String név();

    /**
     * Az alakzattípus ikonja
     * @return az ikon
     */
    public abstract javax.swing.ImageIcon ikon();

    /**
     * A végpont megváltoztatása
     * @param p az új végpont
     */
    public void vég(Point p)    { végpont.x = p.x;  végpont.y = p.y; }

    /**
     * A befoglaló téglalap meghatározása
     * @return a téglalap
     */
    protected Rectangle2D keret()
    {
        int	x = Math.min(kezdőpont.x, végpont.x);
        int y = Math.min(kezdőpont.y, végpont.y);
        int w = Math.abs(kezdőpont.x - végpont.x);
        int h = Math.abs(kezdőpont.y - végpont.y);
        return new Rectangle2D.Double(x + 0.5, y + 0.5, w, h);
    }

    private static final float[]    ds = {10.0f, 5.0f};
    private static final float[]    dp = {3.0f, 3.0f};
    private static final float[]    dsp = {10.0f, 5.0f, 3.0f, 5.0f};

    /**
     * Vonalstílus létrehozása
     * @return a jellemzőknek megfelelő vonalstílus
     */
    protected BasicStroke vonalstílus()
    {
        switch ( stílusérték )
        {
            case SZAGGATOTT:
                return new BasicStroke(vastagság, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL,
                                       0.0f, ds, 0.0f);

            case PONTOZOTT:
                return new BasicStroke(vastagság, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL,
                                       0.0f, dp, 0.0f);
            case SZAGGATOTTPONTOZOTT:
                return new BasicStroke(vastagság, BasicStroke.CAP_BUTT, BasicStroke.JOIN_BEVEL,
                                       0.0f, dsp, 0.0f);
            default:
                return new BasicStroke(vastagság);
        }
    }
}
