import java.awt.event.*;
import javax.swing.*;
import java.awt.*;

public class Rajz extends JFrame
{
    private static final Szakasz    szakasz = new Szakasz();            // szakasz prototípus
    private static final Téglalap   téglalap = new Téglalap();          // téglalap prototípus
    private static final Ellipszis  ellipszis = new Ellipszis();        // ellipszis prototípus

    private static final ImageIcon  üres = new ImageIcon(Rajz.class.getResource("ikonok/üres.png"));
    private static final ImageIcon  teli = new ImageIcon(Rajz.class.getResource("ikonok/teli.png"));
    private static final ImageIcon  zoom = new ImageIcon(Rajz.class.getResource("ikonok/zoom.png"));

    private Terület     terület;                    // rajzolási terület
    private StatusBar   státusz;                    // állapotsor
    private Alakzat     alakzat = szakasz;          // az aktuálisan kiválasztott alakzat típusa
    private Color       vonal = Color.black;        // vonalszín
    private Color       töltő = Color.black;        // kitöltési szín
    private boolean     töltött = false;            // kitöltött-e az alakzat
    private float       vastagság = 1.0f;           // vonalvastagság
    private int         stílus = Alakzat.NORMÁL;    // vonalstílus

    private AbstractAction  új = new AbstractAction("Új", new ImageIcon(Rajz.class.getResource("ikonok/új.png")))
    {
        public void actionPerformed(ActionEvent e)
        {
            terület.új();
            státusz.setText(3, "" + terület.nagyítás());
            setTitle("Névtelen");
        }
    };

    private AbstractAction  nyit = new AbstractAction("Megnyitás", new ImageIcon(Rajz.class.getResource("ikonok/nyit.png")))
    {
        public void actionPerformed(ActionEvent e)
        {
            String  fn = terület.nyit();
            if ( fn == null )   return;
            setTitle(fn);
            státusz.setText(3, "" + terület.nagyítás());
        }
    };

    private AbstractAction  ment = new AbstractAction("Mentés", new ImageIcon(Rajz.class.getResource("ikonok/ment.png")))
    {
        public void actionPerformed(ActionEvent e)
        {
            String  fn = terület.ment();
            if ( fn != null )   setTitle(fn);
        }
    };

    private AbstractAction  kilép = new AbstractAction("Kilépés")
    {
        public void actionPerformed(ActionEvent e)
        {
            kilépés();
        }
    };

    private WindowAdapter   bezár = new WindowAdapter()
    {
        @Override
        public void windowClosing(WindowEvent e)
        {
            kilépés();
        }
    };

    private void kilépés()
    {
        if ( terület.változott() )
        {
            if ( JOptionPane.showConfirmDialog(rootPane,
                        "Akar menteni kilépés előtt?",
                        "A rajz változott",
                        JOptionPane.YES_NO_OPTION) == JOptionPane.YES_OPTION )
                terület.ment();
        }
        System.exit(0);
    }

    private AbstractAction  szakaszalakzat = new AbstractAction("Szakasz", szakasz.ikon())
    {
        public void actionPerformed(ActionEvent e)
        {
            alakzat = szakasz;
            státusz.setIcon(0, alakzat.ikon());
            státusz.setText(0, alakzat.név());
        }
    };
    private AbstractAction  téglalapalakzat = new AbstractAction("Téglalap", téglalap.ikon())
    {
        public void actionPerformed(ActionEvent e)
        {
            alakzat = téglalap;
            státusz.setIcon(0, alakzat.ikon());
            státusz.setText(0, alakzat.név());
        }
    };
    private AbstractAction  ellipszisalakzat = new AbstractAction("Ellipszis", ellipszis.ikon())
    {
        public void actionPerformed(ActionEvent e)
        {
            alakzat = ellipszis;
            státusz.setIcon(0, alakzat.ikon());
            státusz.setText(0, alakzat.név());
        }
    };

    private AbstractAction  kitöltés = new AbstractAction("Üres/Teli", üres)
    {
        public void actionPerformed(ActionEvent e)
        {
            töltött = !töltött;
            if ( töltött )
            {
                putValue(Action.SMALL_ICON, teli);
                státusz.setText(2, "Kitöltött");
                státusz.setIcon(2, teli);
            }
            else
            {
                putValue(Action.SMALL_ICON, üres);
                státusz.setText(2, "Üres");
                státusz.setIcon(2, üres);
            }
        }
    };

    private VastagságDlg    vastagdlg = new VastagságDlg(this, "Vonal vastagsága");
    private AbstractAction  vonalvastagság = new AbstractAction("Vonalvastagság")
    {
        public void actionPerformed(ActionEvent e)
        {
            vastagdlg.setValue(vastagság);
            vastagdlg.setVisible(true);
            if ( vastagdlg.getButtonCode() != OKCancelDialog.OK )   return;
            vastagság = vastagdlg.getValue();
            státusz.setText(1, "Vastagság: " + vastagság);
        }
    };

    private AbstractAction  normálvonal = new AbstractAction("Normál vonal")
    {
        public void actionPerformed(ActionEvent e)
        {
            stílus = Alakzat.NORMÁL;
        }
    };

    private AbstractAction  szaggatottvonal = new AbstractAction("Szaggatott vonal")
    {
        public void actionPerformed(ActionEvent e)
        {
            stílus = Alakzat.SZAGGATOTT;
        }
    };

    private AbstractAction  pontozottvonal = new AbstractAction("Pontozott vonal")
    {
        public void actionPerformed(ActionEvent e)
        {
            stílus = Alakzat.PONTOZOTT;
        }
    };

    private AbstractAction  szaggatottpontozottvonal = new AbstractAction("Szaggatott-Pontozott vonal")
    {
        public void actionPerformed(ActionEvent e)
        {
            stílus = Alakzat.SZAGGATOTTPONTOZOTT;
        }
    };

    private AbstractAction  vonalszín = new AbstractAction("Vonalszín", new ImageIcon(Rajz.class.getResource("ikonok/vonal.png")))
    {
        public void actionPerformed(ActionEvent e)
        {
            Color   c = JColorChooser.showDialog(getRootPane(), "Vonalszín", vonal);
            if ( c == null )   return;
            vonal = c;
        }
    };

    private AbstractAction  töltőszín = new AbstractAction("Kitöltési szín", new ImageIcon(Rajz.class.getResource("ikonok/töltő.png")))
    {
        public void actionPerformed(ActionEvent e)
        {
            Color   c = JColorChooser.showDialog(getRootPane(), "Kitöltési szín", vonal);
            if ( c == null )   return;
            töltő = c;
        }
    };

    private ZoomDlg zoomdlg = new ZoomDlg(this, "Nagyítás mértéke", 1, 8, 1, 1);
    private AbstractAction  nagyítás = new AbstractAction("Nagyítás", zoom)
    {
        public void actionPerformed(ActionEvent e)
        {
            zoomdlg.setValue(terület.nagyítás());
            zoomdlg.setVisible(true);
            if ( zoomdlg.getButtonCode() != OKCancelDialog.OK ) return;
            terület.nagyítás(zoomdlg.getValue());
            státusz.setText(3, "" + terület.nagyítás());
        }
    };

    public Rajz()
    {
        felület();
        addWindowListener(bezár);
        setTitle("Névtelen");
        setSize(800, 600);
        setVisible(true);
    }

    private void felület()
    {
        JMenuBar    menü = new JMenuBar();
        JMenu       fájl = new JMenu("Fájl");
        fájl.setMnemonic('F');
        fájl.add(új);
        fájl.add(nyit);
        fájl.add(ment);
        fájl.addSeparator();
        fájl.add(kilép);
        menü.add(fájl);
        JMenu       alakzatok = new JMenu("Alakzatok");
        alakzatok.setMnemonic('A');
        JMenuItem   elem;
        elem = alakzatok.add(szakaszalakzat);
        elem.setMnemonic('S');
        elem = alakzatok.add(téglalapalakzat);
        elem.setMnemonic('T');
        elem = alakzatok.add(ellipszisalakzat);
        elem.setMnemonic('E');
        menü.add(alakzatok);
        JMenu       jellemzők = new JMenu("Jellemzők");
        jellemzők.setMnemonic('J');
        elem = jellemzők.add(kitöltés);
        elem.setMnemonic('T');
        jellemzők.addSeparator();
        jellemzők.add(vonalvastagság);
        jellemzők.addSeparator();
        jellemzők.add(normálvonal);
        jellemzők.add(szaggatottvonal);
        jellemzők.add(pontozottvonal);
        jellemzők.add(szaggatottpontozottvonal);
        jellemzők.addSeparator();
        jellemzők.add(vonalszín);
        jellemzők.add(töltőszín);
        jellemzők.addSeparator();
        elem = jellemzők.add(nagyítás);
        elem.setMnemonic('N');
        menü.add(jellemzők);

        JToolBar    eszköztár = new JToolBar();
        eszköztár.add(új);
        eszköztár.add(nyit);
        eszköztár.add(ment);
        eszköztár.addSeparator();
        eszköztár.add(szakaszalakzat);
        eszköztár.add(téglalapalakzat);
        eszköztár.add(ellipszisalakzat);
        eszköztár.addSeparator();
        eszköztár.add(kitöltés);
        eszköztár.addSeparator();
        eszköztár.add(vonalszín);
        eszköztár.add(töltőszín);
        eszköztár.addSeparator();
        eszköztár.add(nagyítás);

        státusz = new StatusBar(6);
        státusz.setIcon(0, alakzat.ikon());
        státusz.setText(0, alakzat.név());
        státusz.setWidth(0, 120);
        státusz.setText(1, "Vastagság: " + vastagság);
        státusz.setWidth(1, 120);
        státusz.setText(2, "Üres");
        státusz.setIcon(2, üres);
        státusz.setIcon(3, zoom);
        státusz.setText(3, "" + 1);
        státusz.setHeight(20);
        for ( int i = 2; i < 6; i++ )   státusz.setWidth(i, 80);

        terület = new Terület(this);

        setLayout(new BorderLayout());
        setJMenuBar(menü);
        add("North", eszköztár);
        add("Center", new JScrollPane(terület));
        add("South", státusz);
    }

    /** A státuszsorban az adott indexű cella feliratának állítása */
    public void felirat(int index, String str)
    {
        státusz.setText(index, str);
    }

    /** kiválasztott alakzat létrehozása a pont és az aktuális jellemzők alapján */
    public Alakzat alakzat(Point p)
    {
        return alakzat.másol(p, vonal, töltő, töltött, vastagság, stílus);
    }

    public static void main(String[] args)
    {
        new Rajz();
    }
}
