import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

public class TestDialog extends JDialog
{
    private static final String[]   típusok = { "Gömb", "Kocka", "Tetraéder", "Oktaéder",
                                                "Henger", "Négyzetes", "Háromszöges",
                                                "Kúp", "NGúla" };
    public static final int FELVESZ = 1;
    public static final int VÉGE = 0;

    private int     gombkód = VÉGE;
    private Test    test;

    private JLabel  típuscímke;
    private JLabel  méretcímke;
    private JLabel  magasságcímke;

    private JComboBox   típus;
    private JTextField  méret;
    private JTextField  magasság;

    private JButton felveszgomb;
    private JButton végegomb;

    public TestDialog()
    {
        super((JFrame)null, "Test megadása", true);
        setDefaultCloseOperation(WindowConstants.HIDE_ON_CLOSE);
		felveszgomb = new JButton("Felvesz");
		felveszgomb.addActionListener(felveszakció);
		felveszgomb.setMnemonic('F');
		végegomb = new JButton("Vége");
		végegomb.addActionListener(végeakció);
		JPanel  gombpanel = new JPanel(new FlowLayout());
		gombpanel.add(felveszgomb);
		gombpanel.add(végegomb);

        típuscímke = new JLabel("Típus");
        méretcímke = new JLabel("Méret");
        magasságcímke = new JLabel("Magasság");
        típus = new JComboBox(típusok);
        méret = new JTextField();
        magasság = new JTextField();
        típuscímke.setLabelFor(típus);
        méretcímke.setLabelFor(méret);
        magasságcímke.setLabelFor(magasság);
        JPanel  adatpanel = new JPanel(new GridLayout(3, 2));
        adatpanel.add(típuscímke);
        adatpanel.add(típus);
        adatpanel.add(méretcímke);
        adatpanel.add(méret);
        adatpanel.add(magasságcímke);
        adatpanel.add(magasság);

        setLayout(new BorderLayout());
        add("Center", adatpanel);
        add("South", gombpanel);
        pack();
    }

    public void mutat() { setVisible(true); }

    public int gombKód()    { return gombkód; }

    public Test adat()      { return test; }

    private boolean létrehoz()
    {
        double  mér, mag;
        try
        {
            mér = Double.parseDouble(méret.getText());
            if ( mér <= 0.0 )   return false;
        }
        catch (Exception e)
        {
            return false;
        }
        try
        {
            mag = Double.parseDouble(magasság.getText());
        }
        catch (Exception e)
        {
            mag = -1.0;
        }
        switch ( típus.getSelectedIndex() )
        {
            case 0: test = new Gömb(mér);           return true;
            case 1: test = new Kocka(mér);          return true;
            case 2: test = new Tetraéder(mér);      return true;
            case 3: test = new Oktaéder(mér);       return true;
            case 4: if ( mag <= 0 )                 return false;
                    test = new Henger(mér, mag);    return true;
            case 5: if ( mag <= 0 )                 return false;
                    test = new Négyzetes(mér, mag); return true;
            case 6: if ( mag <= 0 )                 return false;
                    test = new Háromszöges(mér, mag);   return true;
            case 7: if ( mag <= 0 )                 return false;
                    test = new Kúp(mér, mag);       return true;
            case 8: if ( mag <= 0 )                 return false;
                    test = new NGúla(mér, mag);     return true;
            default:
        }
        return false;
    }

	private AbstractAction	felveszakció =
		new AbstractAction()
		{
			public void actionPerformed(ActionEvent e)
			{
                if ( létrehoz() )
                {
                    gombkód = FELVESZ;
                    TestDialog.this.setVisible(false);
                }
			}
		};

        private AbstractAction végeakció =
		new AbstractAction()
		{
			public void actionPerformed(ActionEvent e)
			{
                gombkód = VÉGE;
                TestDialog.this.dispose();
			}
		};
}
